#ifndef CONTENT_ITEMS_PAGE_H
#define CONTENT_ITEMS_PAGE_H

#include <MApplicationPage>

class ContentItemsPagePrivate;

/**
 * @class ContentItemsPage
 * @ingroup PublicAPI
 * @credential relevance::RelevanceAllContentTypes Needed for finding results
 * @credential smartsearch::RelevanceAllContentTypes Needed for finding results
 * @brief Page used to show the the content list and support searching and picking items.
 *
 * ContentItemsPage provides configurable API for showing content items and making selections.
 * This API extends the usage of SearchContentItemPage, SelectSingleContentItemsPage and
 * SelectMultipleContentItemsPage. Below is examples how to create Search, Single and Multiple pages
 * with current functionality.
 * If you want to handle itemClicked differently then just connect it to your own slot.
 *
 *
 * @section Using as SinglePicker
 * When using as Single picker the clicked item stays highlighted and itemClicked
 * is emitted.
 * @code
 * // create new page
 * ContentItemsPage *m_page = new ContentItemsPage (this);
 * // connect itemClicked to selectSingleItem slot
 * connect (m_page, SIGNAL (itemClicked(const QString&)),
 *          m_page, SLOT (selectSingleItem(const QString&)));
 * // to close single picker connect to your slot were you can
 * // ask the selection with m_page->selectedItems () and then
 * // m_page->dismiss ();
 * connect (m_page, SIGNAL (itemClicked(const QString&)),
 *          this, SLOT (selected(const QString&)));
 * // appear the page
 * m_page->appear (myWindow, MSceneWindow::DestroyWhenDismissed);
 * // make sure your current page is appeared when picker is closed
 * connect(page, SIGNAL(backButtonClicked()), myCurrentPage, SLOT(appear()));
 * @endcode
 *
 *
 * @section Using as MultiPicker
 * When using as Multi picker the clicked item is selected and selected items
 * view is enabled. Also done / cancel buttons are enabled for user to confirm or 
 * cancel the selection.
 * @code
 * // create new page
 * m_page = new ContentItemsPage (this);
 * // connect itemClicked to toggleSelection slot
 * connect (m_page, SIGNAL (itemClicked(const QString&)),
 *          m_page, SLOT (toggleSelection(const QString&)));
 * // set content type filters
 * m_page->setContentTypes (QStringList () << ContentSearchEngine::ImageType <<
 *                          ContentSearchEngine::VideoType << 
 *                          ContentSearchEngine::EmailType <<
 *                          ContentSearchEngine::PersonContactType);
 * // do we want to user prefilter view
 * m_page->enablePrefilterView (true);
 * // do we want to user done / cancel buttons
 * m_page->enableConfirmationButton (true);
 * // connect done / cancel signals
 * // in selected slot you can ask the selected items with m_page->selectedItems ()
 * connect (m_page, SIGNAL (selectionConfirmed()),
 *          this, SLOT(selected()));                      
 * connect (m_page, SIGNAL (selectionCancelled()),
 *          this, SLOT (cancelled()));
 * // do we want to use selected items page  
 *   m_page->enableSelectedItemsView (true);
 * // appear the page
 * m_page->appear (myWindow, MSceneWindow::DestroyWhenDismissed);
 * @endcode
 *
 * @section Using as Search
 * When using as Search itemClicked it connected to openItem slot, which
 * sends request to libcontentaction to open correct application. Also context
 * menu is enabled, which is triggered by long tapping item or group.
 * @code
 * // create new page
 * m_page = new ContentItemsPage (this);
 * // connect top openItem slot.
 * connect (m_page, SIGNAL (itemClicked(const QString&)),
 *          m_page, SLOT (openItem(const QString&)));
 * // enable context menu
 * m_page->enableContextMenu (true);
 * // show page
 * m_page->appear (myWindow, MSceneWindow::DestroyWhenDismissed);
 * @endcode
 *
 * @author Nokia
 *
 * $Header$
 */
class ContentItemsPage : public MApplicationPage {

    Q_OBJECT

public:
    
    /**
     * Creates the page.
     **/
    ContentItemsPage (QGraphicsItem *parent=0);

    /**
     * Destructor
     **/
    ~ContentItemsPage();

    /**
     * Set text query.
     * @param text Text to set
     **/
    void setTextQuery (const QString &text);

    /**
     * Return text query.
     **/
    QString textQuery ();

    /**
     * Set content types.
     * @param contentTypes Content types to set
     **/
    void setContentTypes (const QStringList &contentTypes=QStringList());

    /**
     * Return content types.
     **/
    QStringList contentTypes ();

    /**
     * Set Selected Items.
     **/
    void setSelectedItems (const QStringList &selectedItems=QStringList());

    /**
     * Return selected Items.
     **/
    QStringList selectedItems ();

    /**
     * Is item currently selected.
     * @param contentItem uri of the checked item.
     **/
    bool isItemSelected (const QString &contentItem);

    /**
     * Enable selected items view.
     **/
    void enableSelectedItemsView (bool enabled=false);

    /**
     * Is selected items dialog enabled.
     **/
    bool isSelectedItemsDialogEnabled ();

    /**
     * Enable confirmation button in toolbar.
     * @param enabled Enable or disable confirmation button.
     **/
    void enableConfirmationButton (bool enabled=false);

    /**
     * Is confirmation button enabled in toolbar.
     **/
    bool isConfirmationButtonEnabled ();

    /**
     * Enable object menu for items.
     * @param enabled Enable or disable context menu.
     */
    void enableContextMenu (bool enabled=false);

    /**
     * Is object menu enabled.
     */
    bool isContextMenuEnabled ();

    /**
     * Enable pre-filter view
     * @param enabled True or false
     */
    void enablePrefilterView (bool enabled=false);

    /**
     * Is pre-filter view enabled
     * @return True / false
     */
    bool isPrefilterViewEnabled ();

    /**
     * Sets the suffix to append in Common layout names.
     * Currently suffix is only applied to Item title layouts.
     * @param suffix Suffix to append.
     */
    void setCommonLayoutSuffix (const QString &suffix);

    /**
     * Return currently set suffix for Common layout names
     */
    QString commonLayoutSuffix ();

    /**
     * Enable search behaviour, in which case search bar will float when
     * list is panned and VKB is opened automatically when page appeared.
     * @param enabled True or false
     */
    void enableSearchBehaviour (bool enabled=false);

    /**
     * Is search behaviour enabled
     * @return True / false
     */
    bool isSearchBehaviourEnabled ();

Q_SIGNALS:

    /**
     * Signal emitted when slection is changed.
     **/
    void selectionChanged ();

    /**
     * Signal emitted when clicking item in the list.
     * @param contentItem uri of the clicked item.
     **/
    void itemClicked (const QString &contentItem);

    /**
     * Signal emitted when clicking confirmation button in toolbar.
     **/
    void selectionConfirmed ();

    /**
     * Signal emitted when clicking cancel button in toolbar.
     */
    void selectionCancelled ();


public Q_SLOTS:

    /**
     * This can be used for selecting item in list.
     * @param contentItem uri of content item to select.
     **/
    void selectItem (const QString &contentItem);

    /**
     * This can be used for unselecting item in list.
     * @param contentItem uri of content item to unselect.
     **/
    void unselectItem (const QString &contentItem);

    /**
     * This can be used to toggle selection of item.
     * @param contentItem uri of the unselected item.
     **/
    void toggleSelection (const QString &contentItem);

    /**
     * This can be used for selecting single item in list. All the other
     * selected items will be unselected.
     * @param contentItem uri of content item to single select.
     **/
    void selectSingleItem (const QString &contentItem);

    /**
     * This can be used for opening content item.
     * @param contentItem uri of content item to open.
     **/
    void openItem (const QString &contentItem);


private:

    /// private implementation and data
    ContentItemsPagePrivate* m_dptr;

    Q_DISABLE_COPY(ContentItemsPage)
};

#endif // CONTENT_ITEMS_PAGE_H
