#ifndef SEARCH_CONTENT_ITEMS_PAGE_H
#define SEARCH_CONTENT_ITEMS_PAGE_H

#include <MApplicationPage>

class ContentItemsPagePrivate;

/**
 * @class SearchContentItemsPage
 * @ingroup PublicAPI
 * @credential relevance::RelevanceAllContentTypes Needed for finding results
 * @credential smartsearch::RelevanceAllContentTypes Needed for finding results
 * @brief The page which is used to show the the content list and support searching
 *
 * This application page can be used when an application needs to perform searching for content. It it not
 * a page for @e picking content as it will not return anything to the caller. It's a create and forget type of
 * page. For picking use SelectSingleContentItemPage or SelectMultipleContentItemsPage.
 *
 * Typical use of this class is:
 *
 * @code
 * SearchContentItemsPage* page = new SearchContentItemsPage;
 *
 * // make sure the current page is shown when the search page is done
 * connect(page, SIGNAL(backButtonClicked()), myCurrentPage, SLOT(appear()));
 * page->appear(myWindow, MSceneWindow::DestroyWhenDismissed );
 * @endcode
 *
 * See the documentation SelectSingleContentItemPage for information about the parameters that can be passed.
 **/
class SearchContentItemsPage : public MApplicationPage {

    Q_OBJECT
    
public:
    
    /**
     * Creates the search page. The @p text_query is a search string that should be "presearched" and it will be saved in the
     * search field which is shown at the top of the screen. The @p preselected_filters is a list of various filters that
     * should be used to narrow down the available content. These filters can be:
     *
     * @li tag uris
     * @li content type uris
     * @li date range uris (needs specification!)
     *
     * @param text_query the optional free text query used to perform the initial search.
     * @param preselected_filters an optional list of filters used to narrow down content.
     * @param parent optional parent item.
     **/
    SearchContentItemsPage (const QString &text_query="", const QStringList &preselected_filters=QStringList(), QGraphicsItem *parent=0);

    /**
     * \brief Destructor
     **/
    ~SearchContentItemsPage();

    /**
     * Retrieves query string
     **/
    QString textQuery();

    /**
     * Sets query string 
     *
     * @param text_query a new query string
     **/
    void setTextQuery(const QString& text_query="");

    /*!
     * \brief grab focus to text search field
     **/
    void focusSearchBox ();

private:

    //! private implementation and data
    ContentItemsPagePrivate* m_dptr;
    
    Q_DISABLE_COPY(SearchContentItemsPage)
};

#endif // SEARCH_CONTENT_ITEMS_PAGE_H
