#ifndef SELECT_MULTIPLE_CONTENT_ITEMS_PAGE_H
#define SELECT_MULTIPLE_CONTENT_ITEMS_PAGE_H

#include <MApplicationPage>

class ContentItemsPagePrivate;

/**
 * @class SelectMultipleContentItemsPage
 * @ingroup PublicAPI
 * @credential relevance::RelevanceAllContentTypes Needed for finding results
 * @credential smartsearch::RelevanceAllContentTypes Needed for finding results
 * @brief The page which is used to show the the content list and support searching
 *
 * This application page can be used when an application needs to select one single content
 * item. Typical use of this class is:
 *
 * @code
 * SelectMultipleContentItemsPage* page = new SelectMultipleContentItemsPage("", QStringList() << "http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#Media" );
 * page->setTitle("Media Picker");
 *
 * // handle selected items
 * connect(page, SIGNAL(contentItemsSelected( const QStringList & )),
 *         this, SLOT  (contentItemsSelected( const QStringList & )));
 *
 * // make sure the current page is shown when the search page is done
 * connect(page, SIGNAL(backButtonClicked()), myCurrentPage, SLOT(appear()));
 *
 * page->appear(myWindow, MSceneWindow::DestroyWhenDismissed );
 * @endcode
 *
 * The QObject::setProperty() method can be used to set extra properties for pickers.
 *
 * Results are emitted through a signal: contentItemsSelected,  when the picker is closed by clicking the @e done button.
 *
 * Signal selectingContentItem, unselectingContentItem as the preview signal, when user select/unselect a content item
 *
 * When user click the back button, just emit backButtonClicked signal,which inherit from MApplicationPage.
 **/
class SelectMultipleContentItemsPage : public MApplicationPage {

    Q_OBJECT
    
public:
    
    /**
     * Creates the page. The @p text_query is a search string that should be "presearched" and it will be saved in the
     * search field which is shown at the top of the screen. The @p preselected_filters is a list of various filters that
     * should be used to narrow down the available content. These filters can be:
     *
     * @li tag uris
     * @li content type uris
     * @li date range uris (needs specification!)
     *
     * The @p preselected_item is an uri to an item that should be preselected in the result list (assuming it is actually
     * found). This can be for instance some previous selection that should be default if the user just presses @e back
     * without selecting anything.
     *
     * @param text_query the optional free text query used to perform the initial search.
     * @param preselected_filters an optional list of filters used to narrow down content.
     * @param preselected_items a list of uris to an optional items that should be preselected.
     * @param parent optional parent item.
     **/
    SelectMultipleContentItemsPage (const QString &text_query="", const QStringList &preselected_filters=QStringList(), const QStringList &preselected_items=QStringList(),
                                    QGraphicsItem *parent=0);

    /**
     * \brief Destructor
     **/
    ~SelectMultipleContentItemsPage();


Q_SIGNALS:

    /**
     * Signal emitted when the user clicks the @e done button. The @p content_items will contain the uris of the selected items. If nothing was selected then the list will be empty. 
     *
     * @param content_items uris of the selected items or an empty list if nothing was selected.
     **/
    void contentItemsSelected( const QStringList &content_items );

    /**
     * Signal emitted when the user clicks the @e cancel button.
     **/
    void contentItemsSelectionCancelled();

    /**
     * Signal emitted when selecting a item in the list, and item become selected.
     * Mostly use the signal for preview.
     *
     * @param content_item uri of the selected item.
     **/
    void selectingContentItem( const QString &content_item );

    /**
     * Signal emitted when unselecting a item in the list, and item become unselected.
     * Mostly use the signal for preview.
     * 
     * @param content_item uri of the unselected item.
     **/
    void unselectingContentItem(const QString &content_item );

private:

    //! private implementation and data
    ContentItemsPagePrivate* m_dptr;

    Q_DISABLE_COPY(SelectMultipleContentItemsPage)
};

#endif // SELECT_MULTIPLE_CONTENT_ITEMS_PAGE_H
